@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2010 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -30,20 +31,17 @@
     GTK_CHECK_TYPE (obj, gnome_cmd_chmod_component_get_type ())
 
 
-typedef struct _GnomeCmdChmodComponent GnomeCmdChmodComponent;
-typedef struct _GnomeCmdChmodComponentPrivate GnomeCmdChmodComponentPrivate;
-typedef struct _GnomeCmdChmodComponentClass GnomeCmdChmodComponentClass;
+struct GnomeCmdChmodComponentPrivate;
 
 
-
-struct _GnomeCmdChmodComponent
+struct GnomeCmdChmodComponent
 {
     GtkVBox parent;
     GnomeCmdChmodComponentPrivate *priv;
 };
 
 
-struct _GnomeCmdChmodComponentClass
+struct GnomeCmdChmodComponentClass
 {
     GtkVBoxClass parent_class;
 
@@ -53,7 +51,7 @@ struct _GnomeCmdChmodComponentClass
 
 GtkWidget *gnome_cmd_chmod_component_new (GnomeVFSFilePermissions perms);
 
-GtkType gnome_cmd_chmod_component_get_type (void);
+GtkType gnome_cmd_chmod_component_get_type ();
 
 GnomeVFSFilePermissions gnome_cmd_chmod_component_get_perms (GnomeCmdChmodComponent *component);
 void gnome_cmd_chmod_component_set_perms (GnomeCmdChmodComponent *component, GnomeVFSFilePermissions perms);
